package hmac

import (
	"hash"

	"gitlab.bad-wolf.fr/wolf/hmac/requestencoder"
)

// SignerOpt are options for the signer
type SignerOpt func(*signer)

// SignerWithHashFunction define the hash function to use for hmac signature
func SignerWithHashFunction(h func() hash.Hash) SignerOpt {
	return func(s *signer) {
		s.hashFunction = h
	}
}

// SignerWithRequestEncoder define the function used to generate the signed
// string based on the request
func SignerWithRequestEncoder(r requestencoder.RequestEncoder) SignerOpt {
	return func(s *signer) {
		s.requestEncoder = r
	}
}

// SignerWithSignatureEncoder define the function used to encode the signature
// Default signature will be raw []byte. Using an encoder you can encode the
// signature in b64 or hex for example
func SignerWithSignatureEncoder(e ByteEncoder) SignerOpt {
	return func(s *signer) {
		s.signatureEncoder = e
	}
}
